<?php
/*
 * -----------------------------------------------------------------------------
 * 
 * <p><b>License and Copyright: </b>The contents of this file are subject to
 * the Educational Community License (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of the License
 * at <a href="http://www.opensource.org/licenses/ecl1.txt">
 * http://www.opensource.org/licenses/ecl1.txt.</a></p>
 * 
 * <p>Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.</p>
 * 
 * <p>The entire file consists of original code. Copyright &copy; 2004-2008
 * Cornell University. All rights reserved.</p>
 * 
 * -----------------------------------------------------------------------------
 */

include  ('rssfunctions.php');

class SiteRSS {
    
	const FOOTER_MENU_ID = "footer";
	const RELATIVE_URL = "http://RELATIVE/";
	const RELATIVE_URL_LENGTH = 16;
    
    /**
     * Grabs RSS content for the website.
     * Takes an url or file location for the rssfeed
     * 
     * Sections of this class file:
     * 
     * Website - grab title, description, and logo from channel
     * Site - grab issue info (css, desc, img) from item with category=site
     * Main Menu - menu list (title, mainMenuID, desc) per mainMenuID.
     * Submenu - submenu list (title, desc, etc.) per mainMenuID.
     *
     * @param string $issueRSSfeed
     */
    
    public function __construct($rss_url = null) {
        $this->feed = new SimplePie($rss_url);
        $this->feed->handle_content_type();
        if ($this->feed->error()) {
        	echo $this->feed->error();
        }
        $this->items = $this->feed->get_items();
    }
    
    /**
     * Website info
     *
     */
    
    /*
     * Grabs the website header title from the channel title.
     */
    public function getWebsiteTitle() {
        if ($this->feed->get_title()) {
            return $this->feed->get_title();
        } else {
            return 'Website title';
        }
    }    
    
    /*
     * Grabs the website header description from the channel desc.
     */
    public function getWebsiteDescription() {
        if ($this->feed->get_description()) {
            return $this->feed->get_description();
        } else {
            return 'Website description';
        }
    }
    
    /*
     * Grabs the website logo from the channel image.
     */
    public function getWebsiteLogo($opt) {
        switch ($opt) {
            case 'url':
                return $this->feed->get_image_url();
                break;
            case 'height':
                return $this->feed->get_image_height();
                break;
            case 'width':
                return $this->feed->get_image_width();
                break;
            case 'alt':
                return $this->feed->get_image_title();
                break;
            case 'link':
                return $this->feed->get_image_link();
                break;
            default:
                return $this->feed->get_image_url();
                break;
        }
    }
    
    /**
     * Site info
     *
     */
    
    /*
     * Grabs the site css from the channel onramp:css custom element.
     */    
    public function getSiteCSS() {
        return "RSS css not being used at this time";
    }

	public function getSiteItemInfo(){
        $itemArray = self::itemInfoByCategory('site');
		return $itemArray[0];		
	}    
    /*
     * Grabs the site title from the item where category = "site".
     */    
    public function getSiteTitle() {
        $itemArray = self::itemInfoByCategory('site');
        $retValue = $itemArray[0]['title'];
//        foreach($itemArray[0]['all'] as $key => $value ){
//			$retValue = $retValue . ":: NS : " . $key;        	
//        	foreach($value as $key2 => $value2 ){
//    	    	$retValue = $retValue . " :: ".$key2."=".$value2;	
//	        }
//        }
        return $retValue;
    }
    
    /*
     * Grabs the site description from the item where category = "site".
     */    
    public function getSiteDescription() {
        $itemArray = self::itemInfoByCategory('site');
        return $itemArray[0]['description'];
    }
    
    /*
     * Grabs the site image from the item enclosure where category = "site".
     */    
    public function getSiteImage() {
        $itemArray = self::itemInfoByCategory('site');
        return $itemArray[0]['large_image']['link'];
    }
    
    /*
     * Grabs the site image from the item enclosure where category = "site".
     */    
    public function getSiteImageText() {
        $itemArray = self::itemInfoByCategory('site');
        return $itemArray[0]['large_image']['title'];
    }
    
    /*
     * Grabs the site keywords from the item where category = "site".
     */    
    public function getSiteKeywords() {
        $itemArray = self::itemInfoByCategory('site');
        return $itemArray[0]['keywords'];
    }
    
    /*
     * Grabs the site meta description from the item where category = "site".
     */    
    public function getSiteMetaDescription() {
        $itemArray = self::itemInfoByCategory('site');
        return $itemArray[0]['metadesc'];
    }
    
    
    /**
     * Main Menu info
     * 
     */
    
    public function getMainMenuList() {
        $itemArray = self::itemInfoByCategory('mainmenu');
        return $itemArray;
    }
    
    public function getMainMenuItemInfo($menuID) {
        $itemArray = self::getMainMenuList();
        foreach ($itemArray as $menuitem) {
            if ($menuID == $menuitem['id']) {
                $menuInfo = $menuitem;
            } else {
                continue;
            }
        }
        return $menuInfo;
    }

    public function getDefaultMainMenuID() {
        $itemArray = self::getMainMenuList();
        $menuID = $itemArray[0]['id'];
        return $menuID;
    }
    
    /**
     * Submenu info
     */
    
    public function getSubmenuList($mainMenuID = null) {
        $submenuArray = array();
        $c = 0;
        $itemArray = self::itemInfoByCategory($mainMenuID);
        if ($mainMenuID == null) {
            return $itemArray;
        } else {
            for ($i=0; $i < count($itemArray); $i++) {
                if (eregi($mainMenuID, $itemArray[$i]['id'])) {
                    $submenuArray[] = $itemArray[$i]; 
                    $c++;
                }
            }
            return $submenuArray;
        }
    }
    
    public function getSubmenuItemInfo($menuID, $submenuID) {
        $itemArray = self::getSubmenuList($menuID);
        foreach ($itemArray as $submenu) {
            if ($submenuID == $submenu['id']) {
                $submenuInfo = $submenu;
            } else {
                continue;
            }
        }
        return $submenuInfo;
    }
    
    public function getDefaultSubmenuID($menuID) {
        $itemArray = self::getSubmenuList($menuID);
        $submenuID = $itemArray[0]['id'];
        return $submenuID;
    }
    
    public function getFooterMenuID() { return self::FOOTER_MENU_ID; }
    
    public function isFooterMenuItem($menuID) {
		if( isset($menuID) && $menuID != null &&
    		$menuID == self::FOOTER_MENU_ID )
    			return true;
    	return false;	
    }
    
    public function getFooterMenuList() {
        return self::getSubmenuList(self::FOOTER_MENU_ID);
    }
    
    public function getFooterExternalHref($footermenuItem) {
    	$href = null;
		if( is_array($footermenuItem['relatedLink'])){
			$href  = $footermenuItem['relatedLink']['linkHref'];
			if( substr_compare($href, self::RELATIVE_URL, 0, self::RELATIVE_URL_LENGTH) == 0 )
				$href = substr($href, self::RELATIVE_URL_LENGTH);			
		}
        return $href;
    }

    /*
     * Return the URL for an image.
     */    
    public function getImage($itemArray,$size='large_image') {
    	$image = $itemArray[$size];
        return $image['link'];
    }
    
    /*
     * Return the alt text for an image.
     */    
    public function getImageText($itemArray,$size='large_image') {
    	$image = $itemArray[$size];
        return $image['title'];
    }

    
    /*
     * Return the URL for an image.
     */    
    public function getLink($itemArray) {
    	$link = null;
		if( is_array($itemArray['relatedLink'])){
			$title = $itemArray['relatedLink']['linkTitle'];
			$href  = $itemArray['relatedLink']['linkHref'];
			$title = (isset($title) && strlen($title) > 0) ? $title : $href;
	    	$link = "<a href=\"".$href."\">".$title."</a>";
		}
        return $link;
    }
    
    
    /*
     * The blue-collar functions
     */

    
    /*
     * Finds the vales of the item element based on its category level.
     * 
     * @param $category_label string
     * @return array
     */
    private function itemInfoByCategory($category_label) {
        $itemArray = array();
        $i = 0;
        if ($items = $this->items) {
            foreach($items as $key => $this->item) {
                if ($categories = $this->item->get_categories()) {
                    foreach ($categories as $category) {
                        $image = getItemImage($this->item);
                        if ($category->get_label() == $category_label) {
                            $itemArray[$i]['id'] = getData($this->item,'guid');
                            $itemArray[$i]['link'] = getData($this->item,'link');
							$itemArray[$i]['relatedLink'] = getRelatedLink($this->item);      
                            $itemArray[$i]['title'] = getData($this->item,'title');
                            $itemArray[$i]['label'] = getAtomData($this->item,'subtitle');
                            $itemArray[$i]['description'] = getData($this->item,'description');         
                            $itemArray[$i]['enclosure'] = $image['default'];    
                            $itemArray[$i]['atomAttr'] = getAtomAttribs($this->item, $key, 'link', 'title');      
                            $itemArray[$i]['zero_image'] = $image[0];
                            $itemArray[$i]['large_image'] = $image[1];
                            $itemArray[$i]['author'] = ($author = $this->item->get_author()) ? $author->get_name() : null;
                            $itemArray[$i]['metadesc'] = getAtomData($this->item,'summary');
                            $itemArray[$i]['keywords'] = getOnfireData($this->item,'keywords');
////DEBUGGING
//$itemArray[$i]['all'] = $this->item->data['child'];
                            $i++;
                        }
                    }
                }
            }
        } else {
            //log error
        }
        return $itemArray;
    }
    
}

?>